package cn.newfeifan.mall.module.distri.service.duser;

import java.util.*;
import javax.validation.*;
import cn.newfeifan.mall.module.distri.controller.admin.duser.vo.*;
import cn.newfeifan.mall.module.distri.controller.admin.sharepath.vo.SharePathSaveReqVO;
import cn.newfeifan.mall.module.distri.dal.dataobject.duser.DuserDO;
import cn.newfeifan.mall.framework.common.pojo.PageResult;
import cn.newfeifan.mall.module.member.controller.admin.user.vo.MemberUserPageReqVO;
import cn.newfeifan.mall.module.member.controller.admin.user.vo.MemberUserRespVO;

/**
 * 推荐用户 Service 接口
 *
 * @author 非繁人
 */
public interface DuserService {

    /**
     * 创建推荐用户
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createDuser(@Valid DuserSaveReqVO createReqVO);

    /**
     * 更新推荐用户
     *
     * @param updateReqVO 更新信息
     */
    void updateDuser(@Valid DuserSaveReqVO updateReqVO);

    /**
     * 删除推荐用户
     *
     * @param id 编号
     */
    void deleteDuser(Long id);

    /**
     * 获得推荐用户
     *
     * @param id 编号
     * @return 推荐用户
     */
    DuserDO getDuser(Long id);

    /**
     * 获得推荐用户分页
     *
     * @param pageReqVO 分页查询
     * @return 推荐用户分页
     */
    PageResult<DuserDO> getDuserPage(DuserPageReqVO pageReqVO);


    void hasUserAndCreat(SharePathSaveReqVO saveReqVO);
    void hasUserAndCreat(Long userId);


    void hasUserAndCreat(List<Long> userIds);

    /**
     * 获取所有的用户
     * @return
     */
    List<DuserDO> selectAllUser();


    void getSharePathCount(PageResult<DuserRespVO> result);
    /**
     * 根据ID列表查询出所有的Id
     * @param duserId
     * @return
     */
    List<DuserDO> selectUserByUserIds(List<Long> duserId);

    /**
     * 获取当前推荐人的基础信息
     * @param userId
     * @return
     */
    DuserInfoVO getDuserInfo(Long userId);

    DuserDO getDuserByUser(Long userId);

    List<DuserDO> getDuserByName(String name);

    DuserDO getDuserByMobile(String mobile);

    DuserInfoVO initDuser();

    void updateDuserSocial(Long userId, Long social, Integer socialStatus);

    PageResult<MemberUserRespVO> getMemberUserPage(MemberUserPageReqVO pageVO);
}